==> node-rollup_1.10.1.orig.tar.gz: rollup-1.10.1/test/chunking-form/samples/sanitize-internal-exports/_expected/system/main.js <==
System.register(['./generated-chunk.js'], function (exports, module) {
	'use strict';
	return {
		setters: [function (module) {
			var _setter = {};
			_setter.v1 = module.a;
			_setter.v10 = module.j;
			_setter.v100 = module.aJ;
			_setter.v101 = module.aK;
			_setter.v102 = module.aL;
			_setter.v103 = module.aM;
			_setter.v104 = module.aN;
			_setter.v105 = module.aO;
			_setter.v106 = module.aP;
			_setter.v107 = module.aQ;
			_setter.v108 = module.aR;
			_setter.v109 = module.aS;
			_setter.v11 = module.k;
			_setter.v110 = module.aT;
			_setter.v111 = module.aU;
			_setter.v112 = module.aV;
			_setter.v113 = module.aW;
			_setter.v114 = module.aX;
			_setter.v115 = module.aY;
			_setter.v116 = module.aZ;
			_setter.v117 = module.a_;
			_setter.v118 = module.a$;
			_setter.v119 = module.b0;
			_setter.v12 = module.l;
			_setter.v120 = module.b1;
			_setter.v121 = module.b2;
			_setter.v122 = module.b3;
			_setter.v123 = module.b4;
			_setter.v124 = module.b5;
			_setter.v125 = module.b6;
			_setter.v126 = module.b7;
			_setter.v127 = module.b8;
			_setter.v128 = module.b9;
			_setter.v129 = module.ba;
			_setter.v13 = module.m;
			_setter.v130 = module.bb;
			_setter.v131 = module.bc;
			_setter.v132 = module.bd;
			_setter.v133 = module.be;
			_setter.v134 = module.bf;
			_setter.v135 = module.bg;
			_setter.v136 = module.bh;
			_setter.v137 = module.bi;
			_setter.v138 = module.bj;
			_setter.v139 = module.bk;
			_setter.v14 = module.n;
			_setter.v140 = module.bl;
			_setter.v141 = module.bm;
			_setter.v142 = module.bn;
			_setter.v143 = module.bo;
			_setter.v144 = module.bp;
			_setter.v145 = module.bq;
			_setter.v146 = module.br;
			_setter.v147 = module.bs;
			_setter.v148 = module.bt;
			_setter.v149 = module.bu;
			_setter.v15 = module.o;
			_setter.v150 = module.bv;
			_setter.v151 = module.bw;
			_setter.v152 = module.bx;
			_setter.v153 = module.by;
			_setter.v154 = module.bz;
			_setter.v155 = module.bA;
			_setter.v156 = module.bB;
			_setter.v157 = module.bC;
			_setter.v158 = module.bD;
			_setter.v159 = module.bE;
			_setter.v16 = module.p;
			_setter.v160 = module.bF;
			_setter.v161 = module.bG;
			_setter.v162 = module.bH;
			_setter.v163 = module.bI;
			_setter.v164 = module.bJ;
			_setter.v165 = module.bK;
			_setter.v166 = module.bL;
			_setter.v167 = module.bM;
			_setter.v168 = module.bN;
			_setter.v169 = module.bO;
			_setter.v17 = module.q;
			_setter.v170 = module.bP;
			_setter.v171 = module.bQ;
			_setter.v172 = module.bR;
			_setter.v173 = module.bS;
			_setter.v174 = module.bT;
			_setter.v175 = module.bU;
			_setter.v176 = module.bV;
			_setter.v177 = module.bW;
			_setter.v178 = module.bX;
			_setter.v179 = module.bY;
			_setter.v18 = module.r;
			_setter.v180 = module.bZ;
			_setter.v181 = module.b_;
			_setter.v182 = module.b$;
			_setter.v183 = module.c0;
			_setter.v184 = module.c1;
			_setter.v185 = module.c2;
			_setter.v186 = module.c3;
			_setter.v187 = module.c4;
			_setter.v188 = module.c5;
			_setter.v189 = module.c6;
			_setter.v19 = module.s;
			_setter.v190 = module.c7;
			_setter.v191 = module.c8;
			_setter.v192 = module.c9;
			_setter.v193 = module.ca;
			_setter.v194 = module.cb;
			_setter.v195 = module.cc;
			_setter.v196 = module.cd;
			_setter.v197 = module.ce;
			_setter.v198 = module.cf;
			_setter.v199 = module.cg;
			_setter.v2 = module.b;
			_setter.v20 = module.t;
			_setter.v200 = module.ch;
			_setter.v201 = module.ci;
			_setter.v202 = module.cj;
			_setter.v203 = module.ck;
			_setter.v204 = module.cl;
			_setter.v205 = module.cm;
			_setter.v206 = module.cn;
			_setter.v207 = module.co;
			_setter.v208 = module.cp;
			_setter.v209 = module.cq;
			_setter.v21 = module.u;
			_setter.v210 = module.cr;
			_setter.v211 = module.cs;
			_setter.v212 = module.ct;
			_setter.v213 = module.cu;
			_setter.v214 = module.cv;
			_setter.v215 = module.cw;
			_setter.v216 = module.cx;
			_setter.v217 = module.cy;
			_setter.v218 = module.cz;
			_setter.v219 = module.cA;
			_setter.v22 = module.v;
			_setter.v220 = module.cB;
			_setter.v221 = module.cC;
			_setter.v222 = module.cD;
			_setter.v223 = module.cE;
			_setter.v224 = module.cF;
			_setter.v225 = module.cG;
			_setter.v226 = module.cH;
			_setter.v227 = module.cI;
			_setter.v228 = module.cJ;
			_setter.v229 = module.cK;
			_setter.v23 = module.w;
			_setter.v230 = module.cL;
			_setter.v231 = module.cM;
			_setter.v232 = module.cN;
			_setter.v233 = module.cO;
			_setter.v234 = module.cP;
			_setter.v235 = module.cQ;
			_setter.v236 = module.cR;
			_setter.v237 = module.cS;
			_setter.v238 = module.cT;
			_setter.v239 = module.cU;
			_setter.v24 = module.x;
			_setter.v240 = module.cV;
			_setter.v241 = module.cW;
			_setter.v242 = module.cX;
			_setter.v243 = module.cY;
			_setter.v244 = module.cZ;
			_setter.v245 = module.c_;
			_setter.v246 = module.c$;
			_setter.v247 = module.d0;
			_setter.v248 = module.d1;
			_setter.v249 = module.d2;
			_setter.v25 = module.y;
			_setter.v250 = module.d3;
			_setter.v251 = module.d4;
			_setter.v252 = module.d5;
			_setter.v253 = module.d6;
			_setter.v254 = module.d7;
			_setter.v255 = module.d8;
			_setter.v256 = module.d9;
			_setter.v257 = module.da;
			_setter.v258 = module.db;
			_setter.v259 = module.dc;
			_setter.v26 = module.z;
			_setter.v260 = module.dd;
			_setter.v261 = module.de;
			_setter.v262 = module.df;
			_setter.v263 = module.dg;
			_setter.v264 = module.dh;
			_setter.v265 = module.di;
			_setter.v266 = module.dj;
			_setter.v267 = module.dk;
			_setter.v268 = module.dl;
			_setter.v269 = module.dm;
			_setter.v27 = module.A;
			_setter.v270 = module.dn;
			_setter.v271 = module.dp;
			_setter.v272 = module.dq;
			_setter.v28 = module.B;
			_setter.v29 = module.C;
			_setter.v3 = module.c;
			_setter.v30 = module.D;
			_setter.v31 = module.E;
			_setter.v32 = module.F;
			_setter.v33 = module.G;
			_setter.v34 = module.H;
			_setter.v35 = module.I;
			_setter.v36 = module.J;
			_setter.v37 = module.K;
			_setter.v38 = module.L;
			_setter.v39 = module.M;
			_setter.v4 = module.d;
			_setter.v40 = module.N;
			_setter.v41 = module.O;
			_setter.v42 = module.P;
			_setter.v43 = module.Q;
			_setter.v44 = module.R;
			_setter.v45 = module.S;
			_setter.v46 = module.T;
			_setter.v47 = module.U;
			_setter.v48 = module.V;
			_setter.v49 = module.W;
			_setter.v5 = module.e;
			_setter.v50 = module.X;
			_setter.v51 = module.Y;
			_setter.v52 = module.Z;
			_setter.v53 = module._;
			_setter.v54 = module.$;
			_setter.v55 = module.a0;
			_setter.v56 = module.a1;
			_setter.v57 = module.a2;
			_setter.v58 = module.a3;
			_setter.v59 = module.a4;
			_setter.v6 = module.f;
			_setter.v60 = module.a5;
			_setter.v61 = module.a6;
			_setter.v62 = module.a7;
			_setter.v63 = module.a8;
			_setter.v64 = module.a9;
			_setter.v65 = module.aa;
			_setter.v66 = module.ab;
			_setter.v67 = module.ac;
			_setter.v68 = module.ad;
			_setter.v69 = module.ae;
			_setter.v7 = module.g;
			_setter.v70 = module.af;
			_setter.v71 = module.ag;
			_setter.v72 = module.ah;
			_setter.v73 = module.ai;
			_setter.v74 = module.aj;
			_setter.v75 = module.ak;
			_setter.v76 = module.al;
			_setter.v77 = module.am;
			_setter.v78 = module.an;
			_setter.v79 = module.ao;
			_setter.v8 = module.h;
			_setter.v80 = module.ap;
			_setter.v81 = module.aq;
			_setter.v82 = module.ar;
			_setter.v83 = module.as;
			_setter.v84 = module.at;
			_setter.v85 = module.au;
			_setter.v86 = module.av;
			_setter.v87 = module.aw;
			_setter.v88 = module.ax;
			_setter.v89 = module.ay;
			_setter.v9 = module.i;
			_setter.v90 = module.az;
			_setter.v91 = module.aA;
			_setter.v92 = module.aB;
			_setter.v93 = module.aC;
			_setter.v94 = module.aD;
			_setter.v95 = module.aE;
			_setter.v96 = module.aF;
			_setter.v97 = module.aG;
			_setter.v98 = module.aH;
			_setter.v99 = module.aI;
			exports(_setter);
		}],
		execute: function () {

			const lazy = exports('lazy', module.import('./generated-chunk2.js'));

		}
	};
});

==> node-rollup_1.12.2.orig.tar.gz: rollup-1.12.2/test/chunking-form/samples/sanitize-internal-exports/_expected/system/main.js <==
System.register(['./generated-chunk.js'], function (exports, module) {
	'use strict';
	return {
		setters: [function (module) {
			var _setter = {};
			_setter.v1 = module.a;
			_setter.v10 = module.j;
			_setter.v100 = module.aJ;
			_setter.v101 = module.aK;
			_setter.v102 = module.aL;
			_setter.v103 = module.aM;
			_setter.v104 = module.aN;
			_setter.v105 = module.aO;
			_setter.v106 = module.aP;
			_setter.v107 = module.aQ;
			_setter.v108 = module.aR;
			_setter.v109 = module.aS;
			_setter.v11 = module.k;
			_setter.v110 = module.aT;
			_setter.v111 = module.aU;
			_setter.v112 = module.aV;
			_setter.v113 = module.aW;
			_setter.v114 = module.aX;
			_setter.v115 = module.aY;
			_setter.v116 = module.aZ;
			_setter.v117 = module.a_;
			_setter.v118 = module.a$;
			_setter.v119 = module.b0;
			_setter.v12 = module.l;
			_setter.v120 = module.b1;
			_setter.v121 = module.b2;
			_setter.v122 = module.b3;
			_setter.v123 = module.b4;
			_setter.v124 = module.b5;
			_setter.v125 = module.b6;
			_setter.v126 = module.b7;
			_setter.v127 = module.b8;
			_setter.v128 = module.b9;
			_setter.v129 = module.ba;
			_setter.v13 = module.m;
			_setter.v130 = module.bb;
			_setter.v131 = module.bc;
			_setter.v132 = module.bd;
			_setter.v133 = module.be;
			_setter.v134 = module.bf;
			_setter.v135 = module.bg;
			_setter.v136 = module.bh;
			_setter.v137 = module.bi;
			_setter.v138 = module.bj;
			_setter.v139 = module.bk;
			_setter.v14 = module.n;
			_setter.v140 = module.bl;
			_setter.v141 = module.bm;
			_setter.v142 = module.bn;
			_setter.v143 = module.bo;
			_setter.v144 = module.bp;
			_setter.v145 = module.bq;
			_setter.v146 = module.br;
			_setter.v147 = module.bs;
			_setter.v148 = module.bt;
			_setter.v149 = module.bu;
			_setter.v15 = module.o;
			_setter.v150 = module.bv;
			_setter.v151 = module.bw;
			_setter.v152 = module.bx;
			_setter.v153 = module.by;
			_setter.v154 = module.bz;
			_setter.v155 = module.bA;
			_setter.v156 = module.bB;
			_setter.v157 = module.bC;
			_setter.v158 = module.bD;
			_setter.v159 = module.bE;
			_setter.v16 = module.p;
			_setter.v160 = module.bF;
			_setter.v161 = module.bG;
			_setter.v162 = module.bH;
			_setter.v163 = module.bI;
			_setter.v164 = module.bJ;
			_setter.v165 = module.bK;
			_setter.v166 = module.bL;
			_setter.v167 = module.bM;
			_setter.v168 = module.bN;
			_setter.v169 = module.bO;
			_setter.v17 = module.q;
			_setter.v170 = module.bP;
			_setter.v171 = module.bQ;
			_setter.v172 = module.bR;
			_setter.v173 = module.bS;
			_setter.v174 = module.bT;
			_setter.v175 = module.bU;
			_setter.v176 = module.bV;
			_setter.v177 = module.bW;
			_setter.v178 = module.bX;
			_setter.v179 = module.bY;
			_setter.v18 = module.r;
			_setter.v180 = module.bZ;
			_setter.v181 = module.b_;
			_setter.v182 = module.b$;
			_setter.v183 = module.c0;
			_setter.v184 = module.c1;
			_setter.v185 = module.c2;
			_setter.v186 = module.c3;
			_setter.v187 = module.c4;
			_setter.v188 = module.c5;
			_setter.v189 = module.c6;
			_setter.v19 = module.s;
			_setter.v190 = module.c7;
			_setter.v191 = module.c8;
			_setter.v192 = module.c9;
			_setter.v193 = module.ca;
			_setter.v194 = module.cb;
			_setter.v195 = module.cc;
			_setter.v196 = module.cd;
			_setter.v197 = module.ce;
			_setter.v198 = module.cf;
			_setter.v199 = module.cg;
			_setter.v2 = module.b;
			_setter.v20 = module.t;
			_setter.v200 = module.ch;
			_setter.v201 = module.ci;
			_setter.v202 = module.cj;
			_setter.v203 = module.ck;
			_setter.v204 = module.cl;
			_setter.v205 = module.cm;
			_setter.v206 = module.cn;
			_setter.v207 = module.co;
			_setter.v208 = module.cp;
			_setter.v209 = module.cq;
			_setter.v21 = module.u;
			_setter.v210 = module.cr;
			_setter.v211 = module.cs;
			_setter.v212 = module.ct;
			_setter.v213 = module.cu;
			_setter.v214 = module.cv;
			_setter.v215 = module.cw;
			_setter.v216 = module.cx;
			_setter.v217 = module.cy;
			_setter.v218 = module.cz;
			_setter.v219 = module.cA;
			_setter.v22 = module.v;
			_setter.v220 = module.cB;
			_setter.v221 = module.cC;
			_setter.v222 = module.cD;
			_setter.v223 = module.cE;
			_setter.v224 = module.cF;
			_setter.v225 = module.cG;
			_setter.v226 = module.cH;
			_setter.v227 = module.cI;
			_setter.v228 = module.cJ;
			_setter.v229 = module.cK;
			_setter.v23 = module.w;
			_setter.v230 = module.cL;
			_setter.v231 = module.cM;
			_setter.v232 = module.cN;
			_setter.v233 = module.cO;
			_setter.v234 = module.cP;
			_setter.v235 = module.cQ;
			_setter.v236 = module.cR;
			_setter.v237 = module.cS;
			_setter.v238 = module.cT;
			_setter.v239 = module.cU;
			_setter.v24 = module.x;
			_setter.v240 = module.cV;
			_setter.v241 = module.cW;
			_setter.v242 = module.cX;
			_setter.v243 = module.cY;
			_setter.v244 = module.cZ;
			_setter.v245 = module.c_;
			_setter.v246 = module.c$;
			_setter.v247 = module.d0;
			_setter.v248 = module.d1;
			_setter.v249 = module.d2;
			_setter.v25 = module.y;
			_setter.v250 = module.d3;
			_setter.v251 = module.d4;
			_setter.v252 = module.d5;
			_setter.v253 = module.d6;
			_setter.v254 = module.d7;
			_setter.v255 = module.d8;
			_setter.v256 = module.d9;
			_setter.v257 = module.da;
			_setter.v258 = module.db;
			_setter.v259 = module.dc;
			_setter.v26 = module.z;
			_setter.v260 = module.dd;
			_setter.v261 = module.de;
			_setter.v262 = module.df;
			_setter.v263 = module.dg;
			_setter.v264 = module.dh;
			_setter.v265 = module.di;
			_setter.v266 = module.dj;
			_setter.v267 = module.dk;
			_setter.v268 = module.dl;
			_setter.v269 = module.dm;
			_setter.v27 = module.A;
			_setter.v270 = module.dn;
			_setter.v271 = module.dp;
			_setter.v272 = module.dq;
			_setter.v28 = module.B;
			_setter.v29 = module.C;
			_setter.v3 = module.c;
			_setter.v30 = module.D;
			_setter.v31 = module.E;
			_setter.v32 = module.F;
			_setter.v33 = module.G;
			_setter.v34 = module.H;
			_setter.v35 = module.I;
			_setter.v36 = module.J;
			_setter.v37 = module.K;
			_setter.v38 = module.L;
			_setter.v39 = module.M;
			_setter.v4 = module.d;
			_setter.v40 = module.N;
			_setter.v41 = module.O;
			_setter.v42 = module.P;
			_setter.v43 = module.Q;
			_setter.v44 = module.R;
			_setter.v45 = module.S;
			_setter.v46 = module.T;
			_setter.v47 = module.U;
			_setter.v48 = module.V;
			_setter.v49 = module.W;
			_setter.v5 = module.e;
			_setter.v50 = module.X;
			_setter.v51 = module.Y;
			_setter.v52 = module.Z;
			_setter.v53 = module._;
			_setter.v54 = module.$;
			_setter.v55 = module.a0;
			_setter.v56 = module.a1;
			_setter.v57 = module.a2;
			_setter.v58 = module.a3;
			_setter.v59 = module.a4;
			_setter.v6 = module.f;
			_setter.v60 = module.a5;
			_setter.v61 = module.a6;
			_setter.v62 = module.a7;
			_setter.v63 = module.a8;
			_setter.v64 = module.a9;
			_setter.v65 = module.aa;
			_setter.v66 = module.ab;
			_setter.v67 = module.ac;
			_setter.v68 = module.ad;
			_setter.v69 = module.ae;
			_setter.v7 = module.g;
			_setter.v70 = module.af;
			_setter.v71 = module.ag;
			_setter.v72 = module.ah;
			_setter.v73 = module.ai;
			_setter.v74 = module.aj;
			_setter.v75 = module.ak;
			_setter.v76 = module.al;
			_setter.v77 = module.am;
			_setter.v78 = module.an;
			_setter.v79 = module.ao;
			_setter.v8 = module.h;
			_setter.v80 = module.ap;
			_setter.v81 = module.aq;
			_setter.v82 = module.ar;
			_setter.v83 = module.as;
			_setter.v84 = module.at;
			_setter.v85 = module.au;
			_setter.v86 = module.av;
			_setter.v87 = module.aw;
			_setter.v88 = module.ax;
			_setter.v89 = module.ay;
			_setter.v9 = module.i;
			_setter.v90 = module.az;
			_setter.v91 = module.aA;
			_setter.v92 = module.aB;
			_setter.v93 = module.aC;
			_setter.v94 = module.aD;
			_setter.v95 = module.aE;
			_setter.v96 = module.aF;
			_setter.v97 = module.aG;
			_setter.v98 = module.aH;
			_setter.v99 = module.aI;
			exports(_setter);
		}],
		execute: function () {

			const lazy = exports('lazy', module.import('./generated-lazy.js'));

		}
	};
});
